@@ -26,6 +26,22 @@ from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_core3',sys.modules[__name__])
 
 ################# API ########################
+class CommonInfo(ClassSerializer):
+    """
+    Common info for all Info classes
+
+    cl_templates_locate - templates location
+    cl_dipatch_conf - update config method
+    cl_verbose_set - display appling templates
+    """
+    cl_templates_locate = Array(String)
+    cl_dispatch_conf = String
+    cl_verbose_set = Boolean
+
+    Default = Array(String)
+    CheckOnly = Boolean
+    CheckAll = Boolean
+
 class DataVarsSerializer(ClassSerializer):
     """Serializer for datavars types"""
 
@@ -560,7 +576,7 @@ class CoreWsdl:
     def client_send_message(self, sid, pid, text):
         if self.check_cert_pid(sid, pid):
             self.glob_process_dict[pid]['answer'] = text
-            return Message (type = 'normal', message = "Password send")
+            return Message (type = 'normal', message = "")
         return self.perm_denied
 
     @rpc(Integer, Integer, _returns = Array(Message))
