@@ -24,7 +24,7 @@ from calculate.core.server.api_types import (Field, GroupField, ViewInfo,
 from calculate.lib.datavars import VariableError
 from calculate.lib.utils.files import readLinesFile
 from calculate.lib.cl_lang import getLazyLocalTranslate, setLocalTranslate
-setLocalTranslate('cl_core',sys.modules[__name__])
+setLocalTranslate('cl_core3',sys.modules[__name__])
 
 from calculate.core import datavars
 import traceback
@@ -233,7 +233,7 @@ class CoreWsdl:
         dv.addGroup(_("Groups"),
             normal=('cl_page_count','cl_page_offset'),
             next_label=_("Next"))
-        view = ViewInfo(dv)
+        view = ViewInfo(dv,viewparams=params)
         self.set_cache(sid, 'core_show_groups', "vars", dv, smart=False)
         return view
 
@@ -273,7 +273,7 @@ class CoreWsdl:
         dv.addGroup(None,
             normal=('cl_group_name', 'cl_group_rights'))
 
-        view = ViewInfo(dv)
+        view = ViewInfo(dv,viewparams=params)
 
         group = GroupField(name='',last=True)
         group.fields = []
@@ -365,7 +365,7 @@ class CoreWsdl:
             return False
 
     @rpc(Integer, DetailGroupInfo, _returns = Array(ReturnedMessage))
-    @Dec.core_method(gui=True, title=__('Change the group'),
+    @Dec.core_method(gui=True, title=__("Toggle groups"),
                      command='cl-core-change-group',rights=["edit_group"])
     @catchExcept()
     def core_change_group ( self, sid, info):
@@ -375,7 +375,7 @@ class CoreWsdl:
             dv.importCore()
             dv.flIniFile()
         not_group_msg = [ReturnedMessage(type='error', field='cl_group_add',\
-                         message = _('use --group-name to select the group'))]
+                         message = _("use option --group-name to select the group"))]
         if not info:
             return not_group_msg
         if not info.cl_group_name:
@@ -387,7 +387,7 @@ class CoreWsdl:
                                     field = 'cl_group_name')]
         if info.cl_group_rights == None:
             return [ReturnedMessage(type='error', field='cl_group_rights',\
-                    message=_('use --group-rights to change the permissions'))]
+                    message=_("use option --group-rights to toggle permissions"))]
         try:
             dv.Set('cl_group_rights', info.cl_group_rights)
         except VariableError, e:
@@ -406,13 +406,13 @@ class CoreWsdl:
             dv.flIniFile()
             dv.Get('cl_group_name')
 
-        dv.addGroup(_("Change the group"),
+        dv.addGroup(_("Toggle groups"),
             normal=('cl_group_name', 'cl_group_rights'),
             next_label=_("Done"))
 
-        view = ViewInfo(dv)
+        view = ViewInfo(dv,viewparams=params)
 
-        group = GroupField(name=_("Change the group"), nextlabel=_("Done"), \
+        group = GroupField(name=_("Toggle groups"), nextlabel=_("Done"), \
                            last=True)
         group.fields = []
         group.fields.append(Field(
@@ -506,7 +506,7 @@ class CoreWsdl:
         dv.flIniFile()
         if not info:
             return [ReturnedMessage(type = 'error', field = 'cl_group_name', \
-                    message = _('use --group-name to select the group'))]
+                    message = _("use option --group-name to select the group"))]
         try:
             dv.Set('cl_group_name', info.cl_group_name)
         except VariableError, e:
@@ -525,11 +525,11 @@ class CoreWsdl:
             dv.flIniFile()
             dv.Get('cl_group_name')
 
-        dv.addGroup(_("Deleting the group"),
+        dv.addGroup(_("Delete the group"),
             normal=('cl_group_name', 'cl_group_rights'),
             next_label=_("Delete"))
 
-        view = ViewInfo(dv)
+        view = ViewInfo(dv,viewparams=params)
         self.set_cache(sid, 'core_del_group', "vars", dv, smart=False)
         return view
 
@@ -615,7 +615,7 @@ class CoreWsdl:
         dv.flIniFile()
         if not info:
             return [ReturnedMessage(type = 'error', field = 'cl_group_add',\
-                          message = _('use --add-group to add a group'))]
+                          message = _("use option --add-group to add a group"))]
         try:
             dv.Set('cl_group_add', info.cl_group_add)
         except VariableError, e:
@@ -644,6 +644,6 @@ class CoreWsdl:
             normal=('cl_group_add', 'cl_group_rights'),
             next_label=_("Add"))
 
-        view = ViewInfo(dv)
+        view = ViewInfo(dv,viewparams=params)
         self.set_cache(sid, 'core_add_group', "vars", dv, smart=False)
         return view
