@@ -16,7 +16,7 @@
 
 import pickle, random
 import threading
-import sys, os
+import sys, os, re
 import traceback
 from traceback import print_exc
 from api_types import ReturnProgress,ViewParams,Integer,ViewInfo
@@ -27,6 +27,75 @@ from soaplib.service import rpc
 setLocalTranslate('cl_core3',sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+from calculate.lib.utils.files import process,readFile
+from calculate.lib.utils.content import getCfgFiles
+from itertools import *
+
+class CommonMethods:
+    def dispatchConf(self,filesApply=None):
+        """
+        Common dispatch conf. Using if ._cfg files created.
+        """
+        ORIG,DATA=0,1
+        MTIME,CFGFNAME=0,1
+        FIRST=0
+        cfgFiles = getCfgFiles().items()
+        info = filter(lambda x:filesApply is None or \
+                              x[DATA][FIRST][CFGFNAME] in filesApply,
+               cfgFiles)
+        maxInfo = len(info)
+        for ind,data in enumerate(info):
+            out = []
+            orig,data = data
+            data = data[FIRST]
+            for i,s in enumerate(list(process("diff","-Nu",
+                       orig,data[CFGFNAME]))):
+                if s.startswith('+') and i>1:
+                    out.append('<font color="green">%s</font>'%s)
+                elif s.startswith('-') and i>1:
+                    out.append('<font color="red">%s</font>'%s)
+                else:
+                    out.append(s)
+            self.printPre("<br/>".join(out))
+            self.printSUCCESS(_("({one} of {_all}) -- {fname}").format(
+                one=ind+1,_all=maxInfo,fname=orig))
+            answ = self.askChoice(_("Choice action with config:"),
+                    answers=(("zap new",_("Zap new")),
+                             ("use new",_("Use new")),
+                             ("next",_("Next"))))
+            if answ == "next":
+                continue
+            elif answ == "use new":
+                try:
+                    open(orig,'w').write(
+                        readFile(data[CFGFNAME]))
+                    os.unlink(data[CFGFNAME])
+                    if not filesApply is None:
+                        try:
+                            i = filesApply.index(data[CFGFNAME])
+                            filesApply[i] = orig
+                        except Exception as e:
+                            print str(e)
+                except Exception as e:
+                    print str(e)
+                    self.printERROR(
+                        _("Failed to copy {ffrom} to {fto}").format(
+                         ffrom=data[CFGFNAME],fto=orig))
+                    continue
+            elif answ == "zap new":
+                try:
+                    os.unlink(data[CFGFNAME])
+                    if not filesApply is None:
+                        try:
+                            filesApply.remove(data[CFGFNAME])
+                        except Exception as e:
+                            print str(e)
+                except Exception as e:
+                    self.printERROR(
+                        _("Failed to remove %s")%data[CFGFNAME])
+        return True
+
+
 def commonView(self,sid,params,arg):
     dv = self.get_cache(sid,arg,"vars")
     if not dv:
@@ -102,6 +171,7 @@ def safetyWrapper(native_errors=(Exception,),
         def tmp(self,*args,**kwargs):
             error = None
             try:
+                res = False
                 try:
                     res = f(self,*args,**kwargs)
                 except EOFError as e:
@@ -268,7 +338,7 @@ class CoreWsdl():
         else:
             return 1
 
-    class Common:
+    class Common(CommonMethods):
         """ class to interact with the processes """
         def __init__(self, process_dict, progress_dict, table_dict,
                      frame_list, pid):
@@ -316,7 +386,7 @@ class CoreWsdl():
         def getAnswer(self):
             import time
             while self.process_dict['answer'] == None:
-                time.sleep (2)
+                time.sleep (0.5)
             res = self.process_dict['answer']
             self.process_dict['answer'] = None
             self.frame_list.pop(len(self.frame_list) - 1)
@@ -346,11 +416,19 @@ class CoreWsdl():
 
         def addMessage(self, type = 'normal', message = None, id = None):
             from api_types import Message
-            message = Message(type = type, message = message, id = id)
+            reClean = re.compile('\[(?:\d+;)?\d+m')
+            message = Message(type = type,
+                message = None if message is None else \
+                    reClean.sub('',filter(lambda x:x>= ' ',message)), id = id)
             self.frame_list.append(message)
+            #if len(self.frame_list)>500:
+            #    self.frame_list.pop(0)
 
         def printSUCCESS(self, message = ''):
             self.addMessage(type = 'normal', message = message)
+
+        def printPre(self, message = ''):
+            self.addMessage(type = 'pre', message = message)
         
         def printDefault(self, message = ''):
             self.addMessage(type = 'plain', message = message)
@@ -383,6 +461,15 @@ class CoreWsdl():
             self.addMessage(type = 'endTask', message = result)
             self.setProgress(100, progress_message)
 
+        def askConfirm(self, message):
+            self.addMessage(type = 'confirm', message = message)
+            return self.getAnswer()
+
+        def askChoice(self,message,answers=[("yes","Yes"),("no","No")]):
+            self.addMessage(type = 'choice',message="%s|%s"%(message,
+                        ",".join(map(lambda x:"%s(%s)"%(x[0],x[1]),answers))))
+            return self.getAnswer()
+
         def askQuestion(self, message):
             self.addMessage(type = 'question', message = message)
             return self.getAnswer()
@@ -411,7 +498,6 @@ class CoreWsdl():
         #def cache(self, param):
             #sid = self.process_dict['sid']
             #self.args[sid] = collections.OrderedDict()
-
     def startprocess (self, sid, target=None, method=None, method_name=None, \
                       auto_delete=False, args_proc = {}):
         """ start process """
@@ -442,7 +528,8 @@ class CoreWsdl():
                      self.glob_table_dict[pid], \
                      self.glob_frame_list[pid], pid)
 
-        if hasattr (com.__class__.__bases__[1], '__init__'):
+        if len(com.__class__.__bases__)>1 and \
+            hasattr (com.__class__.__bases__[1], '__init__'):
             com.__class__.__bases__[1].__init__(com)
         # start helper
         p = multiprocessing.Process(target = self.target_helper,\
@@ -458,6 +545,7 @@ class CoreWsdl():
             watcher.start()
         return str(pid)
 
+
     # wrap all method
     def target_helper(self, com, target_proc, method_name, *args_proc):
         if not os.path.exists(self.pids):
