@@ -157,6 +157,8 @@ def get_method_argparser(view, args, cl_core = False):
     parser = argparse.ArgumentParser(prog=progr, add_help=False,
                                  formatter_class=RawAndDefaultsHelpFormatter)
 
+    if view.groups is None:
+        return parser
     for Group in getlist(view.groups):
         if not Group.fields:
             continue
@@ -182,7 +184,11 @@ def get_method_argparser(view, args, cl_core = False):
                         #data['nargs'] = '?'
                         data['const'] = val
                         data['metavar'] = ""
-                        data['help'] = help.get(val,field.help)
+                        if hasattr(field,"value") and field.value == val:
+                            data['help'] = help.get(val,field.help) + \
+                                " " + _("(by default)")
+                        else:
+                            data['help'] = help.get(val,field.help)
                         lgroup.add_argument(field.opt.syntax.format(choice=val),
                                             **data)
                     continue
