@@ -21,12 +21,13 @@ from api_types import ViewInfo
 from calculate.core.client.progressbar import Bar,Percentage,ETA,ProgressBar
 from calculate.lib.cl_progressbar import ClProgressDialog,ClMessageBox
 from calculate.lib.utils.text import tableReport
+from calculate.lib.utils.files import getch
 from cert_cmd import parse
 import sys, termios
 import os
 import re
 from methods_func import getErrorOnParam
-from func import shortTraceback
+from func import shortTraceback,CommonMethods
 from fcntl import ioctl
 from array import array
 import threading
@@ -45,12 +46,13 @@ class replaceClass():
             curThread = threading.currentThread()
             curThread.lang = os.environ["LANG"]
         com = target(self.no_progress,self.gui_progress,self.gui_warning)
-        if hasattr (com.__class__.__bases__[1], '__init__'):
+        if len(com.__class__.__bases__)>1 and \
+            hasattr (com.__class__.__bases__[1], '__init__'):
             com.__class__.__bases__[1].__init__(com)
         self.method_status = 0 if getattr(com, method)(*args_proc) else 1
         return 0
 
-    class Common:
+    class Common(CommonMethods):
         """ class to interact with the processes """
         reClearTags = re.compile("<.*?>")
         def __init__(self, no_progress, gui_progress,gui_warning):
@@ -184,6 +186,10 @@ class replaceClass():
             message = self.clearTags(message)
             self.color_print.defaultPrint(message+"\n")
 
+        def printPre(self,message = ''):
+            for line in message.split('<br/>'):
+                self.printDefault(line)
+
         def clearTags(self,s):
             """
             Remove tags from text
@@ -212,7 +218,8 @@ class replaceClass():
                         return "\033[%s;%sm%s\033[0m"%(bg,fg,text)
                 return text
             reFont = re.compile("<font (.*?)>(.*?)</font>")
-            return self.reClearTags.sub("",reFont.sub(fontFunc,s))
+            return self.reClearTags.sub(
+                "",reFont.sub(fontFunc,s)).replace("&nbsp;"," ")
             #return self.reClearTags.sub("",s)
 
         def printSUCCESS(self, message = '', type = None, id = None):
@@ -223,9 +230,8 @@ class replaceClass():
                         for line in message.splitlines():
                             self.color_print.printSUCCESS(self.clearTags(line))
                         return
-                if message:
-                    for line in message.splitlines():
-                        self.color_print.printSUCCESS(self.clearTags(line))
+                for line in message.splitlines():
+                    self.color_print.printSUCCESS(self.clearTags(line))
 
         def printWARNING(self, message):
             if self.progressbar and not self.no_progress \
@@ -273,8 +279,61 @@ class replaceClass():
                 self.color_print.printOK(self.clearTags(result))
             self.setProgress(100, progress_message)
 
+        def askConfirm(self,message):
+            colorPrint = color_print()
+            print
+            while True:
+                try:
+                    ask = raw_input(message+ '? (yes/no): ')
+                except KeyboardInterrupt:
+                    ask = 'no'
+                    print
+                if ask.lower() in ['n', 'no']:
+                    colorPrint.printERROR(_('Manually interrupted'))
+                    return "no"
+                if ask.lower() in ['y', 'yes']:
+                    return "yes"
+
+        def askChoice(self,message,answers=[("yes","Yes"),("no","No")]):
+            colorPrint = color_print()
+            print
+            # ability answer by first letter
+            FIRSTLETTER = 0
+            VALUE,COMMENT = 0,1
+            answerByChar = map(lambda x:x[VALUE][FIRSTLETTER],answers)
+            if filter(lambda x:answerByChar.count(x) > 1,answerByChar):
+                useGetChar = False
+            else:
+                useGetChar = True
+            while True:
+                outMessage = message+ ' (%s): '% \
+                                ("/".join(map(lambda x: \
+                                    "%s[%s]"%(x[COMMENT],x[VALUE][FIRSTLETTER]),
+                                                       answers)))
+                if useGetChar:
+                    colorPrint.defaultPrint(outMessage)
+                    ask = getch()
+                    print
+                else:
+                    try:
+                        ask = raw_input(outMessage)
+                    except KeyboardInterrupt:
+                        ask = answers[-1][COMMENT]
+                        print
+                ask = ask.lower()
+                likeAnswers = filter(lambda x:x[VALUE].startswith(ask),answers)
+                if not likeAnswers:
+                    colorPrint.printERROR(_('The answer is not understood'))
+                    continue
+                if len(likeAnswers) == 1:
+                    return likeAnswers[VALUE][FIRSTLETTER]
+                else:
+                    colorPrint.printERROR(_('Ambiguous answer:')+
+                        ",".join(map(lambda x:x[COMMENT],likeAnswers)))
+
         def askQuestion(self, message):
-            return raw_input(message)
+            print
+            return raw_input(message+":")
 
         def askPassword(self, message, twice = False):
             from calculate.lib.utils.common import getpass
@@ -371,8 +430,8 @@ def local_method(metaclass, args, unknown_args):
         try:
             view = getattr(metaObject, method_view_name)(0, view_obj)
         except AttributeError:
-            colorPrint.printERROR (_('Method not found: '), method_view_name)
-
+            colorPrint.printERROR (_('Method not found: ')+ method_view_name)
+            return 1
         try:
             method_parser = get_method_argparser(view, args, cl_core = True)
         except Exception as e:
@@ -684,6 +743,17 @@ class Table(tableReport):
         self.printReport(printRows=False)
         return "\n".join(self.res)
 
+class Methods(replaceClass.Common,object):
+    _instance = None
+    def __new__(cls, *args, **kwargs):
+        if not cls._instance:
+            cls._instance = super(Methods, cls).__new__(
+                                cls, *args, **kwargs)
+        return cls._instance
+
+    def __init__(self):
+        replaceClass.Common.__init__(self,True,False,False)
+
 def printTable(data, header=None):
     try:
         return Table(None,header,data,colSpan=0).printTable()
