@@ -26,9 +26,9 @@ import time
 import re
 
 from soaplib.serializers.primitive import String, Boolean, Integer
-from soaplib.serializers.clazz import Array, ClassSerializer
+from soaplib.serializers.clazz import Array
 from soaplib.service import rpc
-from calculate.core.server.api_types import ReturnedMessage
+from calculate.core.server.api_types import ReturnedMessage,CommonInfo
 from calculate.core.server.api_types import ViewInfo, ViewParams
 from calculate.core.server.decorators import Dec
 core_method = Dec.core_method
@@ -39,7 +39,7 @@ from calculate.lib.datavars import Variable
 from calculate.lib.cl_log import log
 from calculate.lib import datavars
 from calculate.lib.utils.files import (runOsCommand,scanDirectory,
-                                       pathJoin,readFile)
+                                       pathJoin,readFile,process)
 from calculate.lib.utils.common import getPasswdUsers,getTupleVersion
 from calculate.lib.utils.portage import isPkgInstalled,reVerSplitToPV
 from calculate.lib.utils.content import getCfgFiles,PkgContents
@@ -53,7 +53,7 @@ setLocalTranslate('cl_core3',sys.modules[__name__])
 
 __ = getLazyLocalTranslate(_)
 
-class CoreSetupInfo(ClassSerializer):
+class CoreSetupInfo(CommonInfo):
     """Parameters for method core setup"""
     cl_core_pkg_name = String
     cl_core_pkg_version = String
@@ -64,8 +64,8 @@ class CoreSetupInfo(ClassSerializer):
     cl_core_pkg_desktop_set = Boolean
     cl_core_pkg_root_set = Boolean
 
-    Default = Array(String)
-    CheckOnly = Boolean
+class DispatchInfo(CommonInfo):
+    pass
 
 class shareUpdateConfigs:
     """Common methods"""
@@ -193,10 +193,15 @@ class updateUserConfigs(shareUpdateConfigs):
                            True)
             else:
                 clVars.Set("cl_merge_pkg", ["%s/%s"%(category,nameProgram)], True)
+            clVars.Set("cl_merge_set","on",True)
             clTempl = ChainProgressTemplate( self.startTask,
                                self.endTask,
                                self.setProgress,
                                clVars, cltObj = False,
+                               printSUCCESS=self.printSUCCESS,
+                               printERROR=self.printERROR,
+                               askConfirm=self.askConfirm,
+                               printWARNING=self.printWARNING,
                                printWarning=False)
             clTempl.onFirstValue = lambda *args: \
                     self.startTask(
@@ -375,6 +380,7 @@ class updateSystemConfigs(shareUpdateConfigs):
                        True)
         else:
             clVars.Set("cl_merge_pkg", ["%s/%s"%(category,nameProgram)], True)
+        clVars.Set("cl_merge_set","on",True)
         clVars.Set("cl_action", 'merge', True)
         configFiles = []
         nameProg = clVars.Get("cl_name")
@@ -396,6 +402,9 @@ class updateSystemConfigs(shareUpdateConfigs):
                            printSUCCESS=self.printSUCCESS,
                            printERROR=self.printERROR,
                            printWARNING=self.printWARNING,
+                           askConfirm=self.askConfirm,
+                           dispatchConf= self.dispatchConf
+                                if not clVars.Get('cl_ebuild_phase') else None,
                            printWarning=False)
         clTempl.onFirstValue = lambda *args: \
             self.startTask(_("System configuring for {nameProgram} package by "
@@ -403,54 +412,7 @@ class updateSystemConfigs(shareUpdateConfigs):
                              nameProgram=nameProgram),
                              progress=True)
         dirsFiles = clTempl.applyTemplates()
-        # fix CONTENTS pkg file
-        cfgs = getCfgFiles()
-        autoUpdateDict = {}
-        for pkg in list(set(clTempl.changedFiles.getPkgs()|
-                        set(["%s/%s"%(category,nameProgram)]))):
-            category = isPkgInstalled(pkg)
-            if category:
-                pkgContents = PkgContents("{CATEGORY}/{PF}".format(
-                           **category[0]))
-                for filename,action in clTempl.changedFiles.getPkgFiles(pkg):
-                    if filename in clTempl.protectedFiles:
-                        pkgContents.removeObject(filename)
-                        continue
-                    if action in (cl_template.ChangedFiles.FILE_MODIFIED,
-                                  cl_template.ChangedFiles.DIR_CREATED,
-                                  cl_template.ChangedFiles.DIR_EXISTS):
-                        pkgContents.addObject(filename)
-                    elif action in (cl_template.ChangedFiles.FILE_REMOVED,
-                                    cl_template.ChangedFiles.DIR_REMOVED):
-                        pkgContents.removeObject(filename)
-                files = set(pkgContents.content.keys())
-                if self.clVars.Get('cl_autoupdate_set') == 'off':
-                    files &= set(clTempl.autoUpdateFiles)
-                for filename in list(files&set(cfgs.keys())):
-                    # get ctime from orig filename
-                    if os.path.exists(filename):
-                        ctime = os.stat(filename).st_ctime
-                    else:
-                        ctime = 0
-                    # if orig filename older that .cfg
-                    cfgs[filename].sort(reverse=True)
-                    if ctime < cfgs[filename][0][0]:
-                        try:
-                            open(filename,'w').write(
-                                readFile(cfgs[filename][0][1]))
-                        except Exception as e:
-                            self.printERROR(str(e))
-                            self.printWARNING(
-                                _("Failed to copy {ffrom} to {fto}").format(
-                                 ffrom=cfgs[filename][0][1],fto=filename))
-                            continue
-                        autoUpdateDict[cfgs[filename][0][1]] = filename
-                    for mtime,fn in cfgs[filename]:
-                        try:
-                            os.unlink(fn)
-                        except Exception as e:
-                            self.printWARNING(_("Failed to remove %s")%fn)
-                pkgContents.writeContents()
+
         nameAndVerPkg = nameProg + "-"+clVars.Get("cl_ver")
         self.endTask()
         if dirsFiles is False:
@@ -474,11 +436,11 @@ class updateSystemConfigs(shareUpdateConfigs):
                             nameFile = "/" + nameFile
                     else:
                         nameFile = nameF
-                    nameFile = autoUpdateDict.get(nameFile,nameFile)
                     if reGrey.search(nameFile):
-                        self.SUCCESS(" "*5 + "<font color=\"dark gray\">%s</font>"%nameFile)
+                        self.SUCCESS("&nbsp;"*5 + \
+                            "<font color=\"dark gray\">%s</font>"%nameFile)
                     else:
-                        self.SUCCESS(" "*5 + nameFile)
+                        self.SUCCESS("&nbsp;"*5 + nameFile)
         else:
             self.logger.warn(_("Template not found"))
         if flagUpdate:
@@ -588,7 +550,7 @@ class CoreWsdl:
             install_meth = type("CommonCore",(self.Common,
                                 PackageUpdater, object), {})
             pid = self.startprocess(sid, target=install_meth,
-                            method="updateConfig",\
+                            method="updateConfig",
                             method_name="core_setup",
                             args_proc = (dv,))
             returnmess = ReturnedMessage(type = 'pid', message = pid)
@@ -612,7 +574,8 @@ class CoreWsdl:
             expert=('cl_core_pkg_category', 'cl_core_pkg_version',
                     'cl_core_pkg_slot',
                     'cl_core_pkg_path', 'cl_core_pkg_system_set',
-                    'cl_core_pkg_desktop_set', 'cl_core_pkg_root_set'),
+                    'cl_core_pkg_desktop_set', 'cl_core_pkg_root_set',
+                    'cl_templates_locate','cl_verbose_set','cl_dispatch_conf'),
             next_label=_("Setup"))
         return dv
 
@@ -627,3 +590,24 @@ class CoreWsdl:
         self.set_cache(sid, 'core_setup', "vars",dv,smart=False)
         return view
 
+    @rpc(Integer, DispatchInfo, _returns = Array(ReturnedMessage))
+    @core_method(category=__('Configuration'),title=__('Dispatch-conf'),
+        image='computer',command="cl-dispatch-conf",
+        gui=True, rights=['setup'])
+    def core_dispatch ( self, sid, info):
+        """
+        Dispatch-conf
+        """
+        install_meth = self.Common
+        pid = self.startprocess(sid, target=install_meth,
+                        method="dispatchConf",
+                        method_name="core_dispatch",
+                        args_proc = ())
+        returnmess = ReturnedMessage(type = 'pid', message = pid)
+        returnmess.type = "pid"
+        returnmess.message = pid
+        return [returnmess]
+
+    @rpc(Integer, ViewParams,_returns = ViewInfo)
+    def core_dispatch_view (self, sid, params):
+        return ViewInfo()
